@@ -381,19 +381,27 @@ extern "C"
      * basicConstraints extension. Must be used in combination with
      * GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT.
      */
-    GNUTLS_VERIFY_ALLOW_ANY_X509_V1_CA_CRT = 8
+    GNUTLS_VERIFY_ALLOW_ANY_X509_V1_CA_CRT = 8,
+
+    /* Allow certificates to be signed using the broken MD2 algorithm.
+     */
+    GNUTLS_VERIFY_ALLOW_SIGN_RSA_MD2 = 16,
+
+    /* Allow certificates to be signed using the broken MD5 algorithm.
+     */
+    GNUTLS_VERIFY_ALLOW_SIGN_RSA_MD5 = 32
   } gnutls_certificate_verify_flags;
 
   int gnutls_x509_crt_check_issuer (gnutls_x509_crt_t cert,
 				    gnutls_x509_crt_t issuer);
 
-  int gnutls_x509_crt_list_verify (gnutls_x509_crt_t * cert_list,
-				   int cert_list_length,
-				   const gnutls_x509_crt_t * CA_list,
-				   int CA_list_length,
-				   const gnutls_x509_crl_t * CRL_list,
-				   int CRL_list_length,
-				   unsigned int flags, unsigned int *verify);
+  int gnutls_x509_crt_list_verify(const gnutls_x509_crt_t * cert_list,
+				  int cert_list_length,
+				  const gnutls_x509_crt_t * CA_list,
+				  int CA_list_length,
+				  const gnutls_x509_crl_t * CRL_list,
+				  int CRL_list_length,
+				  unsigned int flags, unsigned int *verify);
 
   int gnutls_x509_crt_verify (gnutls_x509_crt_t cert,
 			      const gnutls_x509_crt_t * CA_list,
