@@ -112,8 +112,8 @@ gen_dhe_server_kx (gnutls_session_t session, opaque ** data)
       return ret;
     }
 
-  dh_params = _gnutls_certificate_get_dh_params (cred, session);
-  mpis = _gnutls_get_dh_params (dh_params);
+  dh_params = _gnutls_get_dh_params (cred->dh_params, cred->params_func, session);
+  mpis = _gnutls_dh_params_to_mpi (dh_params);
   if (mpis == NULL)
     {
       gnutls_assert ();
@@ -132,7 +132,7 @@ gen_dhe_server_kx (gnutls_session_t session, opaque ** data)
 
   _gnutls_dh_set_group (session, g, p);
 
-  ret = _gnutls_dh_common_print_server_kx (session, g, p, data);
+  ret = _gnutls_dh_common_print_server_kx (session, g, p, data, 0);
   if (ret < 0)
     {
       gnutls_assert ();
@@ -196,7 +196,7 @@ proc_dhe_server_kx (gnutls_session_t session, opaque * data,
       return GNUTLS_E_INTERNAL_ERROR;
     }
 
-  ret = _gnutls_proc_dh_common_server_kx (session, data, _data_size);
+  ret = _gnutls_proc_dh_common_server_kx (session, data, _data_size, 0);
   if (ret < 0)
     {
       gnutls_assert ();
@@ -257,8 +257,8 @@ proc_dhe_client_kx (gnutls_session_t session, opaque * data,
       return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
     }
 
-  dh_params = _gnutls_certificate_get_dh_params (cred, session);
-  mpis = _gnutls_get_dh_params (dh_params);
+  dh_params = _gnutls_get_dh_params (cred->dh_params, cred->params_func, session);
+  mpis = _gnutls_dh_params_to_mpi (dh_params);
   if (mpis == NULL)
     {
       gnutls_assert ();
