@@ -131,55 +131,17 @@ gnutls_certificate_free_ca_names (gnutls_certificate_credentials_t sc)
   _gnutls_free_datum (&sc->x509_rdn_sequence);
 }
 
-/*-
-  * _gnutls_certificate_get_dh_params - Returns the DH parameters pointer
-  * @sc: is an #gnutls_certificate_credentials_t structure.
-  *
-  * This function will return the dh parameters pointer. This will read the
-  * credentials structure, and cache the output to the session, so later
-  * calls would not examine the credentials (or call a callback).
-  *
-  -*/
-gnutls_dh_params_t
-_gnutls_certificate_get_dh_params (const
-				   gnutls_certificate_credentials_t sc,
-				   gnutls_session_t session)
-{
-  gnutls_params_st params;
-  int ret;
-
-  if (session->internals.params.cert_dh_params)
-    {
-      return session->internals.params.cert_dh_params;
-    }
-
-  if (sc->dh_params)
-    {
-      session->internals.params.cert_dh_params = sc->dh_params;
-    }
-  else if (sc->params_func)
-    {
-      ret = sc->params_func (session, GNUTLS_PARAMS_DH, &params);
-      if (ret == 0 && params.type == GNUTLS_PARAMS_DH)
-	{
-	  session->internals.params.cert_dh_params = params.params.dh;
-	  session->internals.params.free_cert_dh_params = params.deinit;
-	}
-    }
-
-  return session->internals.params.cert_dh_params;
-}
-
 /*-
   * _gnutls_certificate_get_rsa_params - Returns the RSA parameters pointer
-  * @sc: is an #gnutls_certificate_credentials_t structure.
+  * @rsa_params: holds the RSA parameters or NULL.
+  * @func: function to retrieve the parameters or NULL.
+  * @session: The session.
   *
   * This function will return the rsa parameters pointer.
   *
   -*/
 gnutls_rsa_params_t
-_gnutls_certificate_get_rsa_params (const
-				    gnutls_certificate_credentials_t sc,
+_gnutls_certificate_get_rsa_params (gnutls_rsa_params_t rsa_params, gnutls_params_function* func,
 				    gnutls_session_t session)
 {
   gnutls_params_st params;
@@ -190,13 +152,13 @@ _gnutls_certificate_get_rsa_params (const
       return session->internals.params.rsa_params;
     }
 
-  if (sc->rsa_params)
+  if (rsa_params)
     {
-      session->internals.params.rsa_params = sc->rsa_params;
+      session->internals.params.rsa_params = rsa_params;
     }
-  else if (sc->params_func)
+  else if (func)
     {
-      ret = sc->params_func (session, GNUTLS_PARAMS_RSA_EXPORT, &params);
+      ret = func (session, GNUTLS_PARAMS_RSA_EXPORT, &params);
       if (ret == 0 && params.type == GNUTLS_PARAMS_RSA_EXPORT)
 	{
 	  session->internals.params.rsa_params = params.params.rsa_export;
