@@ -22,7 +22,16 @@
  *
  */
 
-const mpi_t *_gnutls_get_dh_params (gnutls_dh_params_t);
+#ifndef GNUTLS_DH_H
+# define GNUTLS_DH_H
+
+const mpi_t *_gnutls_dh_params_to_mpi (gnutls_dh_params_t);
 mpi_t gnutls_calc_dh_secret (mpi_t * ret_x, mpi_t g, mpi_t prime);
 mpi_t gnutls_calc_dh_key (mpi_t f, mpi_t x, mpi_t prime);
 int _gnutls_dh_generate_prime (mpi_t * ret_g, mpi_t * ret_n, uint bits);
+
+gnutls_dh_params_t
+_gnutls_get_dh_params (gnutls_dh_params_t dh_params, gnutls_params_function* func,
+          gnutls_session_t session);
+
+#endif
