@@ -364,10 +364,8 @@ typedef struct gnutls_dh_params_int
 
 typedef struct
 {
-  gnutls_dh_params_t anon_dh_params;
-  int free_anon_dh_params;
-  gnutls_dh_params_t cert_dh_params;
-  int free_cert_dh_params;
+  gnutls_dh_params_t dh_params;
+  int free_dh_params;
   gnutls_rsa_params_t rsa_params;
   int free_rsa_params;
 } internal_params_st;
