@@ -41,6 +41,7 @@
 #include <gnutls_state.h>
 #include <auth_cert.h>
 #include <auth_anon.h>
+#include <auth_psk.h>
 #include <gnutls_algorithms.h>
 #include <gnutls_rsa_export.h>
 
@@ -174,11 +175,8 @@ _gnutls_session_cert_type_supported (gnutls_session_t session,
 inline static void
 deinit_internal_params (gnutls_session_t session)
 {
-  if (session->internals.params.free_anon_dh_params)
-    gnutls_dh_params_deinit (session->internals.params.anon_dh_params);
-
-  if (session->internals.params.free_cert_dh_params)
-    gnutls_dh_params_deinit (session->internals.params.cert_dh_params);
+  if (session->internals.params.free_dh_params)
+    gnutls_dh_params_deinit (session->internals.params.dh_params);
 
   if (session->internals.params.free_rsa_params)
     gnutls_rsa_params_deinit (session->internals.params.rsa_params);
@@ -438,7 +436,17 @@ _gnutls_dh_set_peer_public (gnutls_session_t session, mpi_t public)
     {
     case GNUTLS_CRD_ANON:
       {
-	anon_server_auth_info_t info;
+	anon_auth_info_t info;
+	info = _gnutls_get_auth_info (session);
+	if (info == NULL)
+	  return GNUTLS_E_INTERNAL_ERROR;
+
+	dh = &info->dh;
+	break;
+      }
+    case GNUTLS_CRD_PSK:
+      {
+	psk_auth_info_t info;
 	info = _gnutls_get_auth_info (session);
 	if (info == NULL)
 	  return GNUTLS_E_INTERNAL_ERROR;
@@ -479,7 +487,16 @@ _gnutls_dh_set_secret_bits (gnutls_session_t session, uint bits)
     {
     case GNUTLS_CRD_ANON:
       {
-	anon_server_auth_info_t info;
+	anon_auth_info_t info;
+	info = _gnutls_get_auth_info (session);
+	if (info == NULL)
+	  return GNUTLS_E_INTERNAL_ERROR;
+	info->dh.secret_bits = bits;
+	break;
+      }
+    case GNUTLS_CRD_PSK:
+      {
+	psk_auth_info_t info;
 	info = _gnutls_get_auth_info (session);
 	if (info == NULL)
 	  return GNUTLS_E_INTERNAL_ERROR;
@@ -550,7 +567,17 @@ _gnutls_dh_set_group (gnutls_session_t session, mpi_t gen, mpi_t prime)
     {
     case GNUTLS_CRD_ANON:
       {
-	anon_server_auth_info_t info;
+	anon_auth_info_t info;
+	info = _gnutls_get_auth_info (session);
+	if (info == NULL)
+	  return GNUTLS_E_INTERNAL_ERROR;
+
+	dh = &info->dh;
+	break;
+      }
+    case GNUTLS_CRD_PSK:
+      {
+	psk_auth_info_t info;
 	info = _gnutls_get_auth_info (session);
 	if (info == NULL)
 	  return GNUTLS_E_INTERNAL_ERROR;
