@@ -22,7 +22,7 @@
  *
  */
 
-/* This file was intended to contains functions to be exported in the
+/* This file contains certificate authentication functions to be exported in the
  * API and did not fit elsewhere.
  */
 
@@ -30,6 +30,7 @@
 #include <auth_srp.h>
 #include <auth_anon.h>
 #include <auth_cert.h>
+#include <auth_psk.h>
 #include <gnutls_errors.h>
 #include <gnutls_auth_int.h>
 #include <gnutls_state.h>
@@ -80,8 +81,9 @@ gnutls_dh_get_group (gnutls_session_t session,
 {
   dh_info_st *dh;
   int ret;
-  anon_server_auth_info_t anon_info;
+  anon_auth_info_t anon_info;
   cert_auth_info_t cert_info;
+  psk_auth_info_t psk_info;
 
   switch (gnutls_auth_get_type (session))
     {
@@ -91,6 +93,12 @@ gnutls_dh_get_group (gnutls_session_t session,
 	return GNUTLS_E_INTERNAL_ERROR;
       dh = &anon_info->dh;
       break;
+    case GNUTLS_CRD_PSK:
+      psk_info = _gnutls_get_auth_info (session);
+      if (psk_info == NULL)
+	return GNUTLS_E_INTERNAL_ERROR;
+      dh = &psk_info->dh;
+      break;
     case GNUTLS_CRD_CERTIFICATE:
       cert_info = _gnutls_get_auth_info (session);
       if (cert_info == NULL)
@@ -136,8 +144,9 @@ int
 gnutls_dh_get_pubkey (gnutls_session_t session, gnutls_datum_t * raw_key)
 {
   dh_info_st *dh;
-  anon_server_auth_info_t anon_info;
+  anon_auth_info_t anon_info;
   cert_auth_info_t cert_info;
+  cert_auth_info_t psk_info;
 
   switch (gnutls_auth_get_type (session))
     {
@@ -149,6 +158,14 @@ gnutls_dh_get_pubkey (gnutls_session_t session, gnutls_datum_t * raw_key)
 	dh = &anon_info->dh;
 	break;
       }
+    case GNUTLS_CRD_PSK:
+      {
+	psk_info = _gnutls_get_auth_info (session);
+	if (psk_info == NULL)
+	  return GNUTLS_E_INTERNAL_ERROR;
+	dh = &psk_info->dh;
+	break;
+      }
     case GNUTLS_CRD_CERTIFICATE:
       {
 
@@ -234,7 +251,16 @@ gnutls_dh_get_secret_bits (gnutls_session_t session)
     {
     case GNUTLS_CRD_ANON:
       {
-	anon_server_auth_info_t info;
+	anon_auth_info_t info;
+
+	info = _gnutls_get_auth_info (session);
+	if (info == NULL)
+	  return GNUTLS_E_INTERNAL_ERROR;
+	return info->dh.secret_bits;
+      }
+    case GNUTLS_CRD_PSK:
+      {
+	psk_auth_info_t info;
 
 	info = _gnutls_get_auth_info (session);
 	if (info == NULL)
@@ -276,7 +302,17 @@ gnutls_dh_get_prime_bits (gnutls_session_t session)
     {
     case GNUTLS_CRD_ANON:
       {
-	anon_server_auth_info_t info;
+	anon_auth_info_t info;
+
+	info = _gnutls_get_auth_info (session);
+	if (info == NULL)
+	  return GNUTLS_E_INTERNAL_ERROR;
+	dh = &info->dh;
+	break;
+      }
+    case GNUTLS_CRD_PSK:
+      {
+	psk_auth_info_t info;
 
 	info = _gnutls_get_auth_info (session);
 	if (info == NULL)
@@ -343,7 +379,18 @@ gnutls_dh_get_peers_public_bits (gnutls_session_t session)
     {
     case GNUTLS_CRD_ANON:
       {
-	anon_server_auth_info_t info;
+	anon_auth_info_t info;
+
+	info = _gnutls_get_auth_info (session);
+	if (info == NULL)
+	  return GNUTLS_E_INTERNAL_ERROR;
+
+	dh = &info->dh;
+	break;
+      }
+    case GNUTLS_CRD_PSK:
+      {
+	psk_auth_info_t info;
 
 	info = _gnutls_get_auth_info (session);
 	if (info == NULL)
@@ -511,22 +558,6 @@ gnutls_fingerprint (gnutls_digest_algorithm_t algo,
   return 0;
 }
 
-/**
-  * gnutls_anon_set_server_dh_params - This function will set the DH parameters for a server to use
-  * @res: is a gnutls_anon_server_credentials_t structure
-  * @dh_params: is a structure that holds diffie hellman parameters.
-  *
-  * This function will set the diffie hellman parameters for an anonymous
-  * server to use. These parameters will be used in Anonymous Diffie Hellman 
-  * cipher suites.
-  *
-  **/
-void
-gnutls_anon_set_server_dh_params (gnutls_anon_server_credentials_t res,
-				  gnutls_dh_params_t dh_params)
-{
-  res->dh_params = dh_params;
-}
 
 /**
   * gnutls_certificate_set_dh_params - This function will set the DH parameters for a server to use
@@ -565,23 +596,6 @@ gnutls_certificate_set_params_function (gnutls_certificate_credentials_t res,
   res->params_func = func;
 }
 
-/**
-  * gnutls_anon_set_params_function - This function will set the DH parameters callback
-  * @res: is a gnutls_certificate_credentials_t structure
-  * @func: is the function to be called
-  *
-  * This function will set a callback in order for the server to get the 
-  * diffie hellman parameters for anonymous authentication. The callback should
-  * return zero on success.
-  *
-  **/
-void
-gnutls_anon_set_params_function (gnutls_anon_server_credentials_t res,
-				 gnutls_params_function * func)
-{
-  res->params_func = func;
-}
-
 
 /**
   * gnutls_certificate_set_verify_flags - This function will set the flags to be used at certificate verification
