@@ -877,7 +877,8 @@ error:
   * encryption schemas, or ASCII for the PKCS12 schemas.
   *
   * If the Certificate is PEM encoded it should have a header of "ENCRYPTED PRIVATE KEY",
-  * or "PRIVATE KEY". You only need to specify the flags if the key is DER encoded.
+  * or "PRIVATE KEY". You only need to specify the flags if the key is DER encoded, since
+  * in that case the encryption status cannot be auto-detected.
   *
   * Returns 0 on success.
   *
@@ -890,7 +891,6 @@ gnutls_x509_privkey_import_pkcs8 (gnutls_x509_privkey_t key,
 {
   int result = 0, need_free = 0;
   gnutls_datum_t _data;
-  int encrypted;
 
   if (key == NULL)
     {
@@ -914,7 +914,6 @@ gnutls_x509_privkey_import_pkcs8 (gnutls_x509_privkey_t key,
       result =
 	_gnutls_fbase64_decode (PEM_UNENCRYPTED_PKCS8,
 				data->data, data->size, &out);
-      encrypted = 0;
 
       if (result < 0)
 	{			/* Try the encrypted header 
@@ -929,9 +928,9 @@ gnutls_x509_privkey_import_pkcs8 (gnutls_x509_privkey_t key,
 	      gnutls_assert ();
 	      return result;
 	    }
-
-	  encrypted = 1;
 	}
+      else if (flags == 0)
+	flags |= GNUTLS_PKCS_PLAIN;
 
       _data.data = out;
       _data.size = result;
