@@ -76,8 +76,8 @@ static int x509ctype;
 static int disable_extensions;
 static int debug;
 
-char *psk_username;
-gnutls_datum psk_key;
+char *psk_username = NULL;
+gnutls_datum psk_key = { NULL, 0 };
 
 static gnutls_srp_client_credentials_t srp_cred;
 static gnutls_psk_client_credentials_t psk_cred;
@@ -632,6 +632,19 @@ after_handshake:
 
   for (;;)
     {
+      if (starttls_alarmed && !hd.secure)
+	{
+	  fprintf (stderr, "*** Starting TLS handshake\n");
+	  ret = do_handshake (&hd);
+	  if (ret < 0)
+	    {
+	      fprintf (stderr, "*** Handshake has failed\n");
+	      socket_bye (&hd);
+	      user_term = 1;
+	      break;
+	    }
+	}
+
       FD_ZERO (&rset);
       FD_SET (fileno (stdin), &rset);
       FD_SET (sd, &rset);
@@ -639,30 +652,10 @@ after_handshake:
       maxfd = MAX (fileno (stdin), sd);
       tv.tv_sec = 3;
       tv.tv_usec = 0;
-      err = select (maxfd + 1, &rset, NULL, NULL, &tv);
 
+      err = select (maxfd + 1, &rset, NULL, NULL, &tv);
       if (err < 0)
-	{
-	  if (errno == EINTR && starttls_alarmed)
-	    {
-	      if (hd.secure == 0)
-		{
-		  fprintf (stderr, "*** Starting TLS handshake\n");
-		  ret = do_handshake (&hd);
-		  if (ret < 0)
-		    {
-		      fprintf (stderr, "*** Handshake has failed\n");
-		      socket_bye (&hd);
-		      user_term = 1;
-		    }
-		}
-	      else
-		{
-		  user_term = 1;
-		}
-	    }
-	  continue;
-	}
+	continue;
 
       if (FD_ISSET (sd, &rset))
 	{
