@@ -520,6 +520,13 @@ print_info (gnutls_session session, const char *hostname)
       if (gnutls_psk_server_get_username (session) != NULL)
 	printf ("- PSK authentication. Connected as '%s'\n",
 		gnutls_psk_server_get_username (session));
+      if (kx == GNUTLS_KX_DHE_PSK) {
+      printf ("- DH using prime of %d bits, secret key "
+	      "of %d bits, and peer's public key is %d bits.\n",
+	      gnutls_dh_get_prime_bits (session),
+	      gnutls_dh_get_secret_bits (session),
+	      gnutls_dh_get_peers_public_bits (session));
+      }
       break;
 #endif
     case GNUTLS_CRD_CERTIFICATE:
@@ -615,6 +622,7 @@ print_list (void)
   printf (", RSA-EXPORT");
   printf (", DHE-DSS");
   printf (", DHE-RSA");
+  printf (", DHE-PSK");
   printf (", PSK");
   printf (", SRP");
   printf (", SRP-RSA");
@@ -753,6 +761,8 @@ parse_kx (char **kx, int nkx, int *kx_priority)
 	    kx_priority[j++] = GNUTLS_KX_RSA;
 	  else if (strcasecmp (kx[i], "PSK") == 0)
 	    kx_priority[j++] = GNUTLS_KX_PSK;
+	  else if (strcasecmp (kx[i], "DHE-PSK") == 0)
+	    kx_priority[j++] = GNUTLS_KX_DHE_PSK;
 	  else if (strcasecmp (kx[i], "RSA-EXPORT") == 0)
 	    kx_priority[j++] = GNUTLS_KX_RSA_EXPORT;
 	  else if (strncasecmp (kx[i], "DHE-RSA", 7) == 0)
